summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDaniel Calviño Sánchez <danxuliu@gmail.com>2017-04-19 07:58:18 +0200
committerDaniel Calviño Sánchez <danxuliu@gmail.com>2017-04-21 14:24:37 +0200
commitbbe479bcd94ea9bdcebe973b17487c5ca015934b (patch)
tree934e5f0a913d5900e85ea9f099fba90687de7390
parent72310cdac1d9a4b9dd9b78e0734100a058fb9714 (diff)
downloadnextcloud-server-bbe479bcd94ea9bdcebe973b17487c5ca015934b.tar.gz
nextcloud-server-bbe479bcd94ea9bdcebe973b17487c5ca015934b.zip
Generalize names and descriptions
Signed-off-by: Daniel Calviño Sánchez <danxuliu@gmail.com>
-rw-r--r--.drone.yml4
-rw-r--r--build/acceptance/features/core/NextcloudTestServerLocalHelper.php (renamed from build/acceptance/features/core/NextcloudTestServerDroneHelper.php)8
-rwxr-xr-xbuild/acceptance/run-local.sh (renamed from build/acceptance/run-drone.sh)16
3 files changed, 14 insertions, 14 deletions
diff --git a/.drone.yml b/.drone.yml
index 9996b5df5cf..b768fd3f1ea 100644
--- a/.drone.yml
+++ b/.drone.yml
@@ -481,14 +481,14 @@ pipeline:
acceptance-access-levels:
image: nextcloudci/php7.0:php7.0-7
commands:
- - build/acceptance/run-drone.sh features/access-levels.feature
+ - build/acceptance/run-local.sh features/access-levels.feature
when:
matrix:
TESTS-ACCEPTANCE: access-levels
acceptance-login:
image: nextcloudci/php7.0:php7.0-7
commands:
- - build/acceptance/run-drone.sh features/login.feature
+ - build/acceptance/run-local.sh features/login.feature
when:
matrix:
TESTS-ACCEPTANCE: login
diff --git a/build/acceptance/run-drone.sh b/build/acceptance/run-local.sh
index c90a79c95e0..900b0ba30a4 100755
--- a/build/acceptance/run-drone.sh
+++ b/build/acceptance/run-local.sh
@@ -18,7 +18,8 @@
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Helper script to run the acceptance tests, which test a running Nextcloud
-# instance from the point of view of a real user, in a Drone step.
+# instance from the point of view of a real user, configured to start the
+# Nextcloud server themselves and from their grandparent directory.
#
# The acceptance tests are written in Behat so, besides running the tests, this
# script installs Behat, its dependencies, and some related packages in the
@@ -28,7 +29,8 @@
# snapshot of the whole grandparent directory (no .gitignore file is used) in
# the Git repository. Finally, the acceptance tests also use the Selenium server
# to control a web browser, so this script waits for the Selenium server
-# (provided in its own Drone service) to be ready before running the tests.
+# (which should have been started before executing this script) to be ready
+# before running the tests.
# Exit immediately on errors.
set -o errexit
@@ -51,9 +53,9 @@ ORIGINAL="\
- NextcloudTestServerContext"
REPLACEMENT="\
- NextcloudTestServerContext:\n\
- nextcloudTestServerHelper: NextcloudTestServerDroneHelper\n\
+ nextcloudTestServerHelper: NextcloudTestServerLocalHelper\n\
nextcloudTestServerHelperParameters:"
-sed "s/$ORIGINAL/$REPLACEMENT/" config/behat.yml > config/behat-drone.yml
+sed "s/$ORIGINAL/$REPLACEMENT/" config/behat.yml > config/behat-local.yml
cd ../../
@@ -66,10 +68,8 @@ git add --all && echo 'Default state' | git -c user.name='John Doe' -c user.emai
cd build/acceptance
-# The Selenium server should be ready by now, as Composer typically takes way
-# longer to execute than its startup (which is done in parallel in a Drone
-# service), but just in case.
+# Ensure that the Selenium server is ready before running the tests.
echo "Waiting for Selenium"
timeout 60s bash -c "while ! curl 127.0.0.1:4444 >/dev/null 2>&1; do sleep 1; done"
-vendor/bin/behat --config=config/behat-drone.yml $SCENARIO_TO_RUN
+vendor/bin/behat --config=config/behat-local.yml $SCENARIO_TO_RUN
diff --git a/build/acceptance/features/core/NextcloudTestServerDroneHelper.php b/build/acceptance/features/core/NextcloudTestServerLocalHelper.php
index 23f6db2df97..32b5330c61a 100644
--- a/build/acceptance/features/core/NextcloudTestServerDroneHelper.php
+++ b/build/acceptance/features/core/NextcloudTestServerLocalHelper.php
@@ -22,8 +22,8 @@
*/
/**
- * Helper to manage a Nextcloud test server when acceptance tests are run in a
- * Drone step.
+ * Helper to manage a Nextcloud test server started directly by the acceptance
+ * tests themselves using the PHP built-in web server.
*
* The Nextcloud test server is executed using the PHP built-in web server
* directly from the grandparent directory of the acceptance tests directory
@@ -40,7 +40,7 @@
* by running "occ maintenance:install"). The base URL to access the Nextcloud
* server can be got from "getBaseUrl".
*/
-class NextcloudTestServerDroneHelper implements NextcloudTestServerHelper {
+class NextcloudTestServerLocalHelper implements NextcloudTestServerHelper {
/**
* @var string
@@ -48,7 +48,7 @@ class NextcloudTestServerDroneHelper implements NextcloudTestServerHelper {
private $phpServerPid;
/**
* Creates a new NextcloudTestServerDroneHelper.
*/
public function __construct() {
$this->phpServerPid = "";
@@ -48,7 +48,7 @@ class NextcloudTestServerDroneHelper implements NextcloudTestServerHelper {
private $phpServerPid;
/**
- * Creates a new NextcloudTestServerDroneHelper.
+ * Creates a new NextcloudTestServerLocalHelper.
*/
public function __construct() {